The widgets package
===================

.. automodule:: parceqt.widgets


The gadgets.lexiconchooser module
---------------------------------

.. automodule:: parceqt.widgets.lexiconchooser
    :members:
    :undoc-members:
    :show-inheritance:

